%%% File    : erlog_parse.yrl
%%% Author  : Robert Virding
%%% Purpose : Simple yecc parser for Erlog.
%%%
%%% (C)Robert Virding. This stuff is mine, distributed without
%%% warranty "as is" and may not be used commercially without written
%%% permission.

Nonterminals
term
term1200 term1100 term1050 term1000 term999 term900 term700 term600 term500
term400 term200 term0

xfx1200 fx1200 xfy1100 xfy1050 xfy1000 fy900 xfx700 xfy600 yfx500
yfx400 xfx200 xfy200 fy200
atomic compound_func compound_list compound_curly arg_list list_tail
.

Terminals
char integer float atom string var

'(' ')' '{' '}' '[' ']' '|'
':-' '-->' '?-' ';' '->' ',' '\\+'
'=' '\\=' '==' '\\==' '@<' '@=<' '@>' '@>=' '=..' 'is' '=:=' '=\\=' '<' '=<' '>' '>='
':'
'+' '-' '/\\' '\\/'
'*' '/' '//' 'rem' 'mod' '<<' '>>'
'**' '^' '\\'

dot.

Rootsymbol term.

term -> term1200 dot : '$1'.

term1200 -> term1100 xfx1200 term1100 : {'$2','$1','$3'}.
term1200 -> fx1200 term1100 : {'$1','$2'}.
term1200 -> term1100 : '$1'.

term1100 -> term1050 xfy1100 term1100 : {'$2','$1','$3'}.
term1100 -> term1050 : '$1'.

term1050 -> term1000 xfy1050 term1050 : {'$2','$1','$3'}.
term1050 -> term1000 : '$1'.

term1000 -> term900 xfy1000 term1000 : {',','$1','$3'}.
term1000 -> term900 : '$1'.

term999 -> term900 : '$1'.			%For lists and arguments

term900 -> fy900 term900 : {'$1','$2'}.
term900 -> term700 : '$1'.

term700 -> term600 xfx700 term600 : {'$2','$1','$3'}.
term700 -> term600 : '$1'.

term600 -> term500 xfy600 term600 : {'$2','$1','$3'}.
term600 -> term500 : '$1'.

term500 -> term500 yfx500 term400 : {'$2','$1','$3'}.
term500 -> term400 : '$1'.

term400 -> term400 yfx400 term200 : {'$2','$1','$3'}.
term400 -> term200 : '$1'.

term200 -> term0 xfx200 term0 : {'$2','$1','$3'}.
term200 -> term0 xfy200 term200 : {'$2','$1','$3'}.
term200 -> fy200 term200 : {'$1','$2'}.
term200 -> term0 : '$1'.

%% All the operators.
xfx1200 -> ':-' : ':-'.
xfx1200 -> '-->' : '-->'.

fx1200 -> ':-' : ':-'.
fx1200 -> '?-' : '?-'.

xfy1100 -> ';' : ';'.

xfy1050 -> '->' : '->'.

xfy1000 -> ',' : ','.

fy900 -> '\\+' : '\\+'.

xfx700 -> '=' : '='.
xfx700 -> '\\=' : '\\='.
xfx700 -> '==' : '=='.
xfx700 -> '\\==' : '\\=='.
xfx700 -> '@<' : '@<'.
xfx700 -> '@=<' : '@=<'.
xfx700 -> '@>' : '@>'.
xfx700 -> '@>=' : '@>='.
xfx700 -> '=..' : '=..'.
xfx700 -> 'is' : 'is'.
xfx700 -> '=:=' : '=:='.
xfx700 -> '=\\=' : '=\\='.
xfx700 -> '<' : '<'.
xfx700 -> '=<' : '=<'.
xfx700 -> '>' : '>'.
xfx700 -> '>=' : '>='.

xfy600 -> ':' : ':'.

yfx500 -> '+' : '+'.
yfx500 -> '-' : '-'.
yfx500 -> '/\\' : '/\\'.
yfx500 -> '\\/' : '\\/'.

yfx400 -> '*' : '*'.
yfx400 -> '/' : '/'.
yfx400 -> '//' : '//'.
yfx400 -> 'rem' : 'rem'.
yfx400 -> 'mod' : 'mod'.
yfx400 -> '<<' : '<<'.
yfx400 -> '>>' : '>>'.

xfx200 -> '**' : '**'.

xfy200 -> '^' : '^'.

fy200 -> '-' : '-'.
fy200 -> '\\' : '\\'.

term0 -> atomic : '$1'.
term0 -> var : {val('$1')}.
term0 -> compound_func : '$1'.
term0 -> compound_list : '$1'.
term0 -> compound_curly : '$1'.
term0 -> '(' term1200 ')' : '$2'.

atomic -> atom : val('$1').
atomic -> integer : val('$1').
atomic -> float : val('$1').
atomic -> string : val('$1').
atomic -> '[' ']' : [].

compound_func -> atom '(' term999 arg_list :
	list_to_tuple([val('$1'),'$3'|'$4']).
%	case list_to_tuple([val('$1'),'$3'|'$4']) of
%	    {'.',H,T} -> [H|T];
%	    Struct -> Struct
%	end.

arg_list -> ',' term999 arg_list : ['$2'|'$3'].
arg_list -> ')' : [].

compound_list -> '[' term999 list_tail : ['$2'|'$3'].

list_tail -> ',' term999 list_tail : ['$2'|'$3'].
list_tail -> '|' term999 ']' : '$2'.
list_tail -> ']' : [].

compound_curly -> '{' term1200 '}' : {'{}','$2'}.

Erlang code.

-export([term/1,tokens/1]).

%% Alternate (better) entry point.
term(Tokens) -> parse(tokens(Tokens)).

op(Tok) -> element(1, Tok).
line(Tok) -> element(2, Tok).
val(Tok) -> element(3, Tok).

%% tokens([ErlangTok9) -> [PrologTok].	

%% First Erlang reserved words/symbols which should be atoms.
tokens([{'after',L}|Ts]) -> [{atom,L,'after'}|tokens(Ts)];
tokens([{'begin',L}|Ts]) -> [{atom,L,'begin'}|tokens(Ts)];
tokens([{'case',L}|Ts]) -> [{atom,L,'case'}|tokens(Ts)];
tokens([{'try',L}|Ts]) -> [{atom,L,'try'}|tokens(Ts)];
tokens([{'catch',L}|Ts]) -> [{atom,L,'catch'}|tokens(Ts)];
tokens([{'end',L}|Ts]) -> [{atom,L,'end'}|tokens(Ts)];
tokens([{'fun',L}|Ts]) -> [{atom,L,'fun'}|tokens(Ts)];
tokens([{'if',L}|Ts]) -> [{atom,L,'if'}|tokens(Ts)];
tokens([{'of',L}|Ts]) -> [{atom,L,'of'}|tokens(Ts)];
tokens([{'receive',L}|Ts]) -> [{atom,L,'receive'}|tokens(Ts)];
tokens([{'when',L}|Ts]) -> [{atom,L,'when'}|tokens(Ts)];
tokens([{'andalso',L}|Ts]) -> [{atom,L,'andalso'}|tokens(Ts)];
tokens([{'orelse',L}|Ts]) -> [{atom,L,'orelse'}|tokens(Ts)];
tokens([{'query',L}|Ts]) -> [{atom,L,'query'}|tokens(Ts)];
tokens([{'bnot',L}|Ts]) -> [{atom,L,'bnot'}|tokens(Ts)];
tokens([{'not',L}|Ts]) -> [{atom,L,'not'}|tokens(Ts)];
tokens([{'div',L}|Ts]) -> [{atom,L,'div'}|tokens(Ts)];
%% tokens([{'rem',L}|Ts]) -> [{atom,L,'rem'}|tokens(Ts)];	%Want this
tokens([{'band',L}|Ts]) -> [{atom,L,'band'}|tokens(Ts)];
tokens([{'and',L}|Ts]) -> [{atom,L,'and'}|tokens(Ts)];
tokens([{'bor',L}|Ts]) -> [{atom,L,'bor'}|tokens(Ts)];
tokens([{'bxor',L}|Ts]) -> [{atom,L,'bxor'}|tokens(Ts)];
tokens([{'bsl',L}|Ts]) -> [{atom,L,'bsl'}|tokens(Ts)];
tokens([{'bsr',L}|Ts]) -> [{atom,L,'bsr'}|tokens(Ts)];
tokens([{'or',L}|Ts]) -> [{atom,L,'or'}|tokens(Ts)];
tokens([{'xor',L}|Ts]) -> [{atom,L,'xor'}|tokens(Ts)];
tokens([{'!',L}|Ts]) -> [{atom,L,'!'}|tokens(Ts)];

%% Erlang symbols which must be combined.
%% Cannot check here if they are together, we are satisfied with same line.
tokens([{'--',L},{'>',L}|Ts]) -> [{'-->',L}|tokens(Ts)];
tokens([{'?',L},{'-',L}|Ts]) -> [{'?-',L}|tokens(Ts)];
tokens([{'\\',L},{'+',L}|Ts]) -> [{'\\+',L}|tokens(Ts)];
tokens([{'\\',L},{'=',L}|Ts]) -> [{'\\=',L}|tokens(Ts)];
tokens([{'\\',L},{'==',L}|Ts]) -> [{'\\==',L}|tokens(Ts)];
tokens([{'@',L},{'<',L}|Ts]) -> [{'@<',L}|tokens(Ts)];
tokens([{'@',L},{'=<',L}|Ts]) -> [{'@=<',L}|tokens(Ts)];
tokens([{'@',L},{'>',L}|Ts]) -> [{'@>',L}|tokens(Ts)];
tokens([{'@',L},{'>=',L}|Ts]) -> [{'@>=',L}|tokens(Ts)];
tokens([{'=',L},{'.',L},{'.',L}|Ts]) -> [{'=..',L}|tokens(Ts)];
tokens([{'=',L},{'.',L},{'dot',L}|Ts]) -> [{'=..',L}|tokens(Ts)];
tokens([{'=',L},{':',L},{'=',L}|Ts]) -> [{'=:=',L}|tokens(Ts)];
tokens([{'=',L},{'\\',L},{'=',L}|Ts]) -> [{'=\\=',L}|tokens(Ts)];
tokens([{'/',L},{'\\',L}|Ts]) -> [{'/\\',L}|tokens(Ts)];
tokens([{'/',L},{'/',L}|Ts]) -> [{'//',L}|tokens(Ts)];
tokens([{'*',L},{'*',L}|Ts]) -> [{'**',L}|tokens(Ts)];

%% Erlang atoms which should be Prolog symbols.
tokens([{atom,L,is}|Ts]) -> [{'is',L}|tokens(Ts)];
tokens([{atom,L,mod}|Ts]) -> [{'mod',L}|tokens(Ts)];

%% Erlang symbols which must be split.
tokens([{'--',L}|Ts]) -> [{'-',L},{'-',L}|tokens(Ts)];
tokens([{'++',L}|Ts]) -> [{'+',L},{'+',L}|tokens(Ts)];
tokens([{'||',L}|Ts]) -> [{'|',L},{'|',L}|tokens(Ts)];
tokens([{'<-',L}|Ts]) -> [{'<',L},{'-',L}|tokens(Ts)];
tokens([{'/=',L}|Ts]) -> [{'/',L},{'=',L}|tokens(Ts)];
tokens([{'=/=',L}|Ts]) -> [{'=',L},{'/',L},{'=',L}|tokens(Ts)];

%% And all the rest.
tokens([T|Ts]) -> [T|tokens(Ts)];
tokens([]) -> [].
